==> zio-aws-storagegateway_3-5.17.116.2-sources.jar: zio/aws/storagegateway/model/DeleteChapCredentialsResponse.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.{IqnName, TargetARN}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DeleteChapCredentialsResponse(
    targetARN: Option[TargetARN] = None,
    initiatorName: Option[IqnName] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.DeleteChapCredentialsResponse = {
    import DeleteChapCredentialsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.DeleteChapCredentialsResponse
      .builder()
      .optionallyWith(
        targetARN.map(value => TargetARN.unwrap(value): java.lang.String)
      )(_.targetARN)
      .optionallyWith(
        initiatorName.map(value => IqnName.unwrap(value): java.lang.String)
      )(_.initiatorName)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.DeleteChapCredentialsResponse.ReadOnly =
    zio.aws.storagegateway.model.DeleteChapCredentialsResponse
      .wrap(buildAwsValue())
}
object DeleteChapCredentialsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.DeleteChapCredentialsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.storagegateway.model.DeleteChapCredentialsResponse =
      zio.aws.storagegateway.model.DeleteChapCredentialsResponse(
        targetARN.map(value => value),
        initiatorName.map(value => value)
      )
    def targetARN: Option[TargetARN]
    def initiatorName: Option[IqnName]
    def getTargetARN: ZIO[Any, AwsError, TargetARN] =
      AwsError.unwrapOptionField("targetARN", targetARN)
    def getInitiatorName: ZIO[Any, AwsError, IqnName] =
      AwsError.unwrapOptionField("initiatorName", initiatorName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.DeleteChapCredentialsResponse
  ) extends zio.aws.storagegateway.model.DeleteChapCredentialsResponse.ReadOnly {
    override val targetARN: Option[TargetARN] = scala
      .Option(impl.targetARN())
      .map(value => zio.aws.storagegateway.model.primitives.TargetARN(value))
    override val initiatorName: Option[IqnName] = scala
      .Option(impl.initiatorName())
      .map(value => zio.aws.storagegateway.model.primitives.IqnName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.DeleteChapCredentialsResponse
  ): zio.aws.storagegateway.model.DeleteChapCredentialsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-storagegateway_3-7.21.15.1-sources.jar: zio/aws/storagegateway/model/DeleteChapCredentialsResponse.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.{IqnName, TargetARN}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DeleteChapCredentialsResponse(
    targetARN: Optional[TargetARN] = Optional.Absent,
    initiatorName: Optional[IqnName] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.DeleteChapCredentialsResponse = {
    import DeleteChapCredentialsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.DeleteChapCredentialsResponse
      .builder()
      .optionallyWith(
        targetARN.map(value => TargetARN.unwrap(value): java.lang.String)
      )(_.targetARN)
      .optionallyWith(
        initiatorName.map(value => IqnName.unwrap(value): java.lang.String)
      )(_.initiatorName)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.DeleteChapCredentialsResponse.ReadOnly =
    zio.aws.storagegateway.model.DeleteChapCredentialsResponse
      .wrap(buildAwsValue())
}
object DeleteChapCredentialsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.DeleteChapCredentialsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.storagegateway.model.DeleteChapCredentialsResponse =
      zio.aws.storagegateway.model.DeleteChapCredentialsResponse(
        targetARN.map(value => value),
        initiatorName.map(value => value)
      )
    def targetARN: Optional[TargetARN]
    def initiatorName: Optional[IqnName]
    def getTargetARN: ZIO[Any, AwsError, TargetARN] =
      AwsError.unwrapOptionField("targetARN", targetARN)
    def getInitiatorName: ZIO[Any, AwsError, IqnName] =
      AwsError.unwrapOptionField("initiatorName", initiatorName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.DeleteChapCredentialsResponse
  ) extends zio.aws.storagegateway.model.DeleteChapCredentialsResponse.ReadOnly {
    override val targetARN: Optional[TargetARN] = zio.aws.core.internal
      .optionalFromNullable(impl.targetARN())
      .map(value => zio.aws.storagegateway.model.primitives.TargetARN(value))
    override val initiatorName: Optional[IqnName] = zio.aws.core.internal
      .optionalFromNullable(impl.initiatorName())
      .map(value => zio.aws.storagegateway.model.primitives.IqnName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.DeleteChapCredentialsResponse
  ): zio.aws.storagegateway.model.DeleteChapCredentialsResponse.ReadOnly =
    new Wrapper(impl)
}
